Range-v3: ranges::v3::view::tokenize_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Synopsis of methods | Public Member Functions | List of all members
ranges::v3::view::tokenize_fn Struct Reference
Inheritance diagram for ranges::v3::view::tokenize_fn:

## Synopsis of methods
constexpr tokenize_fn | tokenize {}

## Public Member Functions
template<typename ... Args>
auto | operator() (Args &&...args) const -> decltype(base()(static_cast< Args &&>(args)...))
template<typename Arg0 , typename ... Args>
auto | operator() (Arg0 &&arg0, std::initializer_list< int > subs, Args &&...args) const -> decltype(base()(static_cast< Arg0 &&>(arg0), std::move(subs), static_cast< Args &&>(args)...))
template<typename Arg0 , typename Arg1 , typename ... Args>
auto | operator() (Arg0 &&arg0, Arg1 &&arg1, std::initializer_list< int > subs, Args &&...args) const -> decltype(base()(static_cast< Arg0 &&>(arg0), static_cast< Arg1 &&>(arg1), std::move(subs), static_cast< Args &&>(args)...))
Public Member Functions inherited from ranges::v3::view::tokenizer_impl_fn
template<typename Rng , typename Regex >
tokenize_view< all_t< Rng >, detail::decay_t< Regex >, int > | operator() (Rng &&rng, Regex &&rex, int sub=0, std::regex_constants::match_flag_type flags=std::regex_constants::match_default) const
template<typename Rng , typename Regex >
tokenize_view< all_t< Rng >, detail::decay_t< Regex >, std::vector< int > > | operator() (Rng &&rng, Regex &&rex, std::vector< int > subs, std::regex_constants::match_flag_type flags=std::regex_constants::match_default) const
template<typename Rng , typename Regex >
tokenize_view< all_t< Rng >, detail::decay_t< Regex >, std::initializer_list< int > > | operator() (Rng &&rng, Regex &&rex, std::initializer_list< int > subs, std::regex_constants::match_flag_type flags=std::regex_constants::match_default) const
template<typename Regex >
auto | operator() (Regex &&rex, int sub=0, std::regex_constants::match_flag_type flags=std::regex_constants::match_default) const -> decltype(make_pipeable(std::bind(*this, std::placeholders::_1, bind_forward< Regex >(rex), std::move(sub), std::move(flags))))
template<typename Regex >
auto | operator() (Regex &&rex, std::vector< int > subs, std::regex_constants::match_flag_type flags=std::regex_constants::match_default) const -> decltype(make_pipeable(std::bind(*this, std::placeholders::_1, bind_forward< Regex >(rex), std::move(subs), std::move(flags))))
template<typename Regex >
auto | operator() (Regex &&rex, std::initializer_list< int > subs, std::regex_constants::match_flag_type flags=std::regex_constants::match_default) const -> decltype(make_pipeable(std::bind(*this, std::placeholders::_1, bind_forward< Regex >(rex), std::move(subs), std::move(flags))))